@@ -13,10 +13,12 @@ validate <- function( inet, tnet, steps=50 )
       if( !isSymmetric(inet) && isSymmetric(tnet)) {
          warning("infered network arcs will be consider as undirected edges")
          inet <- .Call("symmetrize",as.double(inet),ncol(inet),PACKAGE="minet")
+		 dim(inet) <- c(ncol(tnet),ncol(tnet))
       }
       else if(isSymmetric(inet) && !isSymmetric(tnet)) {
          warning("true network arcs will be considerd as undirected edges")
          tnet <- .Call("symmetrize",as.double(tnet),ncol(tnet),PACKAGE="minet")
+		 dim(tnet) <- c(ncol(inet),ncol(inet))
       }
       res <- .Call("validate",inet,tnet,min(inet),max(inet),ncol(inet),steps,PACKAGE="minet")
 
